Learn R Programming

slopes (version 1.0.1)

magnolia_xy: Road segments in Magnolia, Seattle

Description

A dataset representing road segments in the Magnolia area of Seattle with X, Y and Z (elevation) dimensions for each coordinate.

Usage

magnolia_xy

Arguments

Format

An object of class sf

Examples

Run this code
names(magnolia_xy)
plot(magnolia_xy["SLOPE_PCT"])

Run the code above in your browser using DataLab