powered by
A dataset representing road segments in the Magnolia area of Seattle with X, Y and Z (elevation) dimensions for each coordinate.
magnolia_xy
An object of class sf
sf
names(magnolia_xy) plot(magnolia_xy["SLOPE_PCT"])
Run the code above in your browser using DataLab